from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as _enum_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApprovalLifecycleState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    APPROVAL_LIFECYCLE_UNSPECIFIED: _ClassVar[ApprovalLifecycleState]
    APPROVAL_LIFECYCLE_REQUESTED: _ClassVar[ApprovalLifecycleState]
    APPROVAL_LIFECYCLE_INTERRUPT_CAPTURED: _ClassVar[ApprovalLifecycleState]
    APPROVAL_LIFECYCLE_DECISION_RECORDED: _ClassVar[ApprovalLifecycleState]
    APPROVAL_LIFECYCLE_RESUME_RECONCILED: _ClassVar[ApprovalLifecycleState]
    APPROVAL_LIFECYCLE_CLEARED: _ClassVar[ApprovalLifecycleState]
APPROVAL_LIFECYCLE_UNSPECIFIED: ApprovalLifecycleState
APPROVAL_LIFECYCLE_REQUESTED: ApprovalLifecycleState
APPROVAL_LIFECYCLE_INTERRUPT_CAPTURED: ApprovalLifecycleState
APPROVAL_LIFECYCLE_DECISION_RECORDED: ApprovalLifecycleState
APPROVAL_LIFECYCLE_RESUME_RECONCILED: ApprovalLifecycleState
APPROVAL_LIFECYCLE_CLEARED: ApprovalLifecycleState

class PendingApproval(_message.Message):
    __slots__ = ("tool_call_id", "tool_name", "message", "args_preview", "requested_at", "from_sub_agent", "sub_agent_name", "child_agent_execution_id", "interrupt_id", "lifecycle_state", "decision_action", "decision_recorded_at")
    TOOL_CALL_ID_FIELD_NUMBER: _ClassVar[int]
    TOOL_NAME_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ARGS_PREVIEW_FIELD_NUMBER: _ClassVar[int]
    REQUESTED_AT_FIELD_NUMBER: _ClassVar[int]
    FROM_SUB_AGENT_FIELD_NUMBER: _ClassVar[int]
    SUB_AGENT_NAME_FIELD_NUMBER: _ClassVar[int]
    CHILD_AGENT_EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    INTERRUPT_ID_FIELD_NUMBER: _ClassVar[int]
    LIFECYCLE_STATE_FIELD_NUMBER: _ClassVar[int]
    DECISION_ACTION_FIELD_NUMBER: _ClassVar[int]
    DECISION_RECORDED_AT_FIELD_NUMBER: _ClassVar[int]
    tool_call_id: str
    tool_name: str
    message: str
    args_preview: str
    requested_at: str
    from_sub_agent: bool
    sub_agent_name: str
    child_agent_execution_id: str
    interrupt_id: str
    lifecycle_state: ApprovalLifecycleState
    decision_action: _enum_pb2.ApprovalAction
    decision_recorded_at: str
    def __init__(self, tool_call_id: _Optional[str] = ..., tool_name: _Optional[str] = ..., message: _Optional[str] = ..., args_preview: _Optional[str] = ..., requested_at: _Optional[str] = ..., from_sub_agent: bool = ..., sub_agent_name: _Optional[str] = ..., child_agent_execution_id: _Optional[str] = ..., interrupt_id: _Optional[str] = ..., lifecycle_state: _Optional[_Union[ApprovalLifecycleState, str]] = ..., decision_action: _Optional[_Union[_enum_pb2.ApprovalAction, str]] = ..., decision_recorded_at: _Optional[str] = ...) -> None: ...

class ChildApprovalNotification(_message.Message):
    __slots__ = ("execution_id", "pending_approvals")
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    PENDING_APPROVALS_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    pending_approvals: _containers.RepeatedCompositeFieldContainer[PendingApproval]
    def __init__(self, execution_id: _Optional[str] = ..., pending_approvals: _Optional[_Iterable[_Union[PendingApproval, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/environment/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/environment/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.environment.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_api__pb2
from ai.stigmer.agentic.environment.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_io__pb2
from ai.stigmer.agentic.environment.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_spec__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/agentic/environment/v1/query.proto\x12!ai.stigmer.agentic.environment.v1\x1a+ai/stigmer/agentic/environment/v1/api.proto\x1a*ai/stigmer/agentic/environment/v1/io.proto\x1a,ai/stigmer/agentic/environment/v1/spec.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\x8c\x05\n\x1a\x45nvironmentQueryController\x12\x96\x01\n\x03get\x12-.ai.stigmer.commons.apiresource.ApiResourceId\x1a..ai.stigmer.agentic.environment.v1.Environment\"0\xc2\xb8\x18,\x08\x03\x10\x35\"\x05value*\x1funauthorized to get environment\x12|\n\x0egetByReference\x12\x34.ai.stigmer.commons.apiresource.ApiResourceReference\x1a..ai.stigmer.agentic.environment.v1.Environment\"\x04\xd0\xb8\x18\x01\x12\xd2\x01\n\x0egetSecretValue\x12>.ai.stigmer.agentic.environment.v1.EnvironmentSecretValueInput\x1a\x33.ai.stigmer.agentic.environment.v1.EnvironmentValue\"K\xc2\xb8\x18G\x08\x19\x10\x35\"\x0e\x65nvironment_id*1unauthorized to read secret values (creator-only)\x12|\n\x04list\x12:.ai.stigmer.agentic.environment.v1.ListEnvironmentsRequest\x1a\x32.ai.stigmer.agentic.environment.v1.EnvironmentList\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+5B\xdc\x01\n%com.ai.stigmer.agentic.environment.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAE\xaa\x02!Ai.Stigmer.Agentic.Environment.V1\xca\x02!Ai\\Stigmer\\Agentic\\Environment\\V1\xe2\x02-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Agentic::Environment::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.environment.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.agentic.environment.v1B\nQueryProtoP\001\242\002\004ASAE\252\002!Ai.Stigmer.Agentic.Environment.V1\312\002!Ai\\Stigmer\\Agentic\\Environment\\V1\342\002-Ai\\Stigmer\\Agentic\\Environment\\V1\\GPBMetadata\352\002%Ai::Stigmer::Agentic::Environment::V1'
  _globals['_ENVIRONMENTQUERYCONTROLLER']._loaded_options = None
  _globals['_ENVIRONMENTQUERYCONTROLLER']._serialized_options = b'\240\377+5'
  _globals['_ENVIRONMENTQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_ENVIRONMENTQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\030,\010\003\0205\"\005value*\037unauthorized to get environment'
  _globals['_ENVIRONMENTQUERYCONTROLLER'].methods_by_name['getByReference']._loaded_options = None
  _globals['_ENVIRONMENTQUERYCONTROLLER'].methods_by_name['getByReference']._serialized_options = b'\320\270\030\001'
  _globals['_ENVIRONMENTQUERYCONTROLLER'].methods_by_name['getSecretValue']._loaded_options = None
  _globals['_ENVIRONMENTQUERYCONTROLLER'].methods_by_name['getSecretValue']._serialized_options = b'\302\270\030G\010\031\0205\"\016environment_id*1unauthorized to read secret values (creator-only)'
  _globals['_ENVIRONMENTQUERYCONTROLLER'].methods_by_name['list']._loaded_options = None
  _globals['_ENVIRONMENTQUERYCONTROLLER'].methods_by_name['list']._serialized_options = b'\320\270\030\001'
  _globals['_ENVIRONMENTQUERYCONTROLLER']._serialized_start=386
  _globals['_ENVIRONMENTQUERYCONTROLLER']._serialized_end=1038
# @@protoc_insertion_point(module_scope)



from ai.stigmer.agentic.workflow.v1 import spec_pb2 as _spec_pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ForkTaskConfig(_message.Message):
    __slots__ = ("branches", "compete")
    BRANCHES_FIELD_NUMBER: _ClassVar[int]
    COMPETE_FIELD_NUMBER: _ClassVar[int]
    branches: _containers.RepeatedCompositeFieldContainer[ForkBranch]
    compete: bool
    def __init__(self, branches: _Optional[_Iterable[_Union[ForkBranch, _Mapping]]] = ..., compete: bool = ...) -> None: ...

class ForkBranch(_message.Message):
    __slots__ = ("name", "do")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DO_FIELD_NUMBER: _ClassVar[int]
    name: str
    do: _containers.RepeatedCompositeFieldContainer[_spec_pb2.WorkflowTask]
    def __init__(self, name: _Optional[str] = ..., do: _Optional[_Iterable[_Union[_spec_pb2.WorkflowTask, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/mcpserver/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/mcpserver/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.mcpserver.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ai/stigmer/agentic/mcpserver/v1/query.proto\x12\x1f\x61i.stigmer.agentic.mcpserver.v1\x1a)ai/stigmer/agentic/mcpserver/v1/api.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xaf\x02\n\x18McpServerQueryController\x12\x92\x01\n\x03get\x12-.ai.stigmer.commons.apiresource.ApiResourceId\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"0\xc2\xb8\x18,\x08\x03\x10,\"\x05value*\x1funauthorized to view mcp server\x12x\n\x0egetByReference\x12\x34.ai.stigmer.commons.apiresource.ApiResourceReference\x1a*.ai.stigmer.agentic.mcpserver.v1.McpServer\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+,B\xd2\x01\n#com.ai.stigmer.agentic.mcpserver.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAM\xaa\x02\x1f\x41i.Stigmer.Agentic.Mcpserver.V1\xca\x02\x1f\x41i\\Stigmer\\Agentic\\Mcpserver\\V1\xe2\x02+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\xea\x02#Ai::Stigmer::Agentic::Mcpserver::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.mcpserver.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.ai.stigmer.agentic.mcpserver.v1B\nQueryProtoP\001\242\002\004ASAM\252\002\037Ai.Stigmer.Agentic.Mcpserver.V1\312\002\037Ai\\Stigmer\\Agentic\\Mcpserver\\V1\342\002+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\352\002#Ai::Stigmer::Agentic::Mcpserver::V1'
  _globals['_MCPSERVERQUERYCONTROLLER']._loaded_options = None
  _globals['_MCPSERVERQUERYCONTROLLER']._serialized_options = b'\240\377+,'
  _globals['_MCPSERVERQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_MCPSERVERQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\030,\010\003\020,\"\005value*\037unauthorized to view mcp server'
  _globals['_MCPSERVERQUERYCONTROLLER'].methods_by_name['getByReference']._loaded_options = None
  _globals['_MCPSERVERQUERYCONTROLLER'].methods_by_name['getByReference']._serialized_options = b'\320\270\030\001'
  _globals['_MCPSERVERQUERYCONTROLLER']._serialized_start=290
  _globals['_MCPSERVERQUERYCONTROLLER']._serialized_end=593
# @@protoc_insertion_point(module_scope)
